# Nikto Module

The module supports Raw, XML and JSON Input from nikto.

However, multiple targets are not supported in JSON. This is due to nikto's implementation.

If you have problems with your table, please ensure that you style your table
in CSS within your report template.

# Unit Tests

```
python -m unittest discover -v -s modules
```